<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        @rowClick="rowClick"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :bottomOffset="250"
        :ajaxFun="ajaxFun"
        :paramObj="paramObj"
        ref="reserveDetailTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
    </basic-container>
  </div>
</template>

<script>
import { mapGetters } from 'vuex'
import {
  delObjReserveDetail,
  fetchReserveDetail
} from '../../../api/warehouse/reservemain'
import ttable from '@/views/common/ztt-table.vue'
export default {
  props: {
    reserveMainId: {
      type: Number,
      default: 0
    },
    visible: {
      type: Boolean,
      default: false
    },
    paramObj: {
      type: Object,
      default: () => {
        return {}
      }
    }
  },
  data() {
    return {
      ajaxFun: fetchReserveDetail,
      resTypeOptions: [],
      mulLocation: [],
      isShowQuery: false,
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'partNo', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 零件编号
          {
            minWidth: '120',
            width: '200',
            prop: 'partNo',
            label: '零件编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 零件名称
          {
            minWidth: '200',
            prop: 'partName',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 规格
          {
            minWidth: '140',
            prop: 'specs',
            label: '规格',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 型号
          {
            minWidth: '120',
            prop: 'partModel',
            label: '型号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 需求数量
          {
            minWidth: '200',
            prop: 'resQty',
            label: '需求数量',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 预留数量
          {
            minWidth: '200',
            prop: 'ppoQty',
            label: '预留数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 出库数量
          {
            minWidth: '140',
            prop: 'outQty',
            label: '出库数量',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 接收数量
          {
            minWidth: '120',
            prop: 'recvQty',
            label: '接收数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 单位
          {
            minWidth: '200',
            prop: 'unit',
            label: '单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 状态
          {
            minWidth: '200',
            prop: 'status',
            label: '状态',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          }
        ],
        toolbar: [],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 200,
          minWidth: 100
        }
      },
      addOrUpdateVisible: false
    }
  },
  components: {
    ttable
  },
  watch: {
    visible: {
      handler(newValue, oldValue) {
        if (newValue) {
          this.$nextTick(() => {
            this.getData()
          })
        }
      },
      immediate: true
    }
  },
  computed: {
    ...mapGetters(['permissions'])
  },

  methods: {
    handleSelectionChange(val) {
      this.mulLocation = val
    },
    // 获取数据列表
    getData() {
      if (this.$refs.reserveDetailTable != undefined) {
        this.$refs.reserveDetailTable.getDataList()
      }
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      if (!this.reserveMainId) {
        this.$message.error('请先保存')
        return
      }
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(
          row == null ? null : row.id,
          this.reserveMainId
        )
      })
    },
    rowClick(row) {
      this.$emit('refreshDataList', row.partId, row.id)
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除ID为' + row.id, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delObjReserveDetail(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    }
  }
}
</script>
